@@ -4,8 +4,8 @@ AudioFile::Info::MP3::Info - Perl extension to get info from MP3 files.
 
 =head1 DESCRIPTION
 
-This is a plugin for AudioFile::Info which uses MP3::ID3Lib to get
-data about MP files.
+This is a plugin for AudioFile::Info which uses MP3::Info to get
+data about MP3 files.
 
 See L<AudioFile::Info> for more details.
 
@@ -20,7 +20,7 @@ use Carp;
 
 use MP3::Info;
 
-our $VERSION = '1.5.0';
+our $VERSION = '1.5.1';
 
 my %data = (artist => 'ARTIST',
             title  => 'TITLE',
